@@ -8,6 +8,7 @@
 
 class Rules;
 class States;
+class Ranges;
 
 #include <bobcat/mstream>
 
@@ -25,12 +26,9 @@ class DFA
 
     std::vector<DFARow> d_row;
     std::vector<Size_tSet> d_stateSet;      // states belonging to a DFA row
-    std::vector<Size_tSet> d_transitSet;    // DFArows already visited by 
-                                            //  determineTailCount
-    //bool d_verbose;
-    bool d_sawACCEPT;           // used by visitTailCount
 
-    size_t d_rule;              // used when computing TailCount values 
+    size_t d_nUsedRanges = 0;             // number of ranges used by this DFA
+    std::vector<bool> d_usedRanges;
 
     static FBB::Mstream s_verbose;  // writes to cout if verbose was set
 
@@ -44,36 +42,19 @@ class DFA
 
         std::vector<DFARow>::const_iterator begin() const;
         std::vector<DFARow>::const_iterator end() const;
+        std::vector<DFARow> const &rows() const;
 
         size_t size() const;
 
         static void setVerbose(bool on);
-
+        
     private:
-        void keepViableTailCounts();
-
         void keepUniqueRows();
         void inspectRows(std::vector<size_t> &unique);
         void shrinkDFA(std::vector<size_t> &unique);
 
 
         size_t available(DFARow const &nextRow);
-
-        void computeTailCounts();
-        void visitTailCount(TailCount &tailCount);
-
-        void determineTailCount(TailCount &tailCount, size_t thisRow,
-                                      TailCount *fmTailCount, size_t fmRow);
-
-        bool setTailCount(TailCount &tailCount, size_t thisRow, 
-                         TailCount *fmTailCount, size_t fmRow);
-        bool setIncTailCount(TailCount::Type type, TailCount &thisTailCount);
-        bool setInitTailCount(TailCount::Type type, TailCount &thisTailCount);
-        bool setNextTailCount(TailCount::Type type,
-                            TailCount &thisTailCount, size_t thisRow,
-                            TailCount &fmTailCount, size_t fmRow);
-        void transitTailCount(DFARow::MapValue const &rangeToRow, 
-                    TailCount *fmTailCount, size_t fmRow);
 };
 
 inline std::vector<DFARow>::const_iterator DFA::begin() const
@@ -86,12 +67,15 @@ inline std::vector<DFARow>::const_iterator DFA::end() const
     return d_row.end();
 }
 
+inline std::vector<DFARow> const &DFA::rows() const
+{
+    return d_row;
+}
+
 inline size_t DFA::size() const
 {
     return d_row.size();
 }
 
-//        void mergeFinalSet();
-
 #endif
 
