@@ -3,20 +3,21 @@
 
 #include <string>
 #include <vector>
+#include <set>
 #include <iosfwd>
 
 #include "../rules/rules.h"
-#include "../dfa/dfa.h"
 
 class States;
 class Ranges;
+class DFA;
     
 class DFAs
 {
     friend std::ostream &operator<<(std::ostream &out, DFAs const &dfas);
 
     public:
-        typedef std::pair<std::string, DFA> Pair;
+        typedef std::pair<std::string, DFA *> Pair;
         typedef std::vector<Pair> DFAInfo;
 
     private:
@@ -28,13 +29,17 @@ class DFAs
         
     public:
         DFAs(Rules &rules, States &states, Ranges &ranges);
+        ~DFAs();
 
         void build();
+        void warnNonViable() const;
         DFAInfo::const_iterator begin() const;
         DFAInfo::const_iterator end() const;
         DFAInfo::const_iterator find(std::string const &key) const;
 
     private:
+        void removeRules(DFA const &dfa, std::set<size_t> &nonViable) const;
+
 };
 
 inline DFAs::DFAInfo::const_iterator DFAs::begin() const
