@@ -3,18 +3,18 @@
 void Generator::lop4(ostream &out) const
 {
     out <<    
-"void " << d_baseclassScope << R"(lop4__()
+"void " << d_baseclassScope << R"(lop4_()
 {
 )";
 
     if (d_debug)
         out << 
 R"(
-    if (s_debug__)
-        s_out__ << "lop4__ matched head `" << d_matched << "'\n"
+    if (s_debug_)
+        s_out_ << "lop4_ matched head `" << d_matched << "'\n"
                 "       re-scan `" << 
                 d_lopMatched.substr(length(), std::string::npos) << "'\n" << 
-                dflush__;
+                dflush_;
 )";
 
         out << 
