@@ -1,12 +1,10 @@
 #include "parser.ih"
 
-spSemUnion Parser::dollar()
+Pattern Parser::dollar()
 {
     if (not d_warnDollars)
         wmsg << "`$' inside regex loses its special meaning" << endl;
     d_warnDollars = true;
 
-    spSemUnion ret(rawText("$"));
-
-    return ret;
+    return rawText("$");
 }
