@@ -2,11 +2,11 @@
 
 void Parser::print()
 {
-    if (d_printTokens && d_token__ != s_ignoreToken)
+    if (d_printTokens && token_() != s_ignoreToken)
     {
-        std::cout << "Token: " << symbol__(d_token__);
+        std::cout << "Token: " << symbol_(token_());
 
-        if (isprint(d_token__) || d_token__ > 0xff)
+        if (isprint(token_()) || token_() > 0xff)
             std::cout << ", text: `" << d_matched << "'\n";
         else
             std::cout << '\n';
