@@ -1,6 +1,6 @@
 #include "pattern.ih"
 
-Pattern::Pattern(States::Pair const &pair)
+Pattern::Pattern(Pair const &pair)
 :
     d_pair(pair)
 {}
