@@ -5,7 +5,7 @@ bool Scanner::moreInput()
     if (popStream())            // first unwind any stacked files
         return true;
 
-    d_endOfInput = true;
+//    d_endOfInput = true;
 
     return insertedCatchAll();
 }
