@@ -18,6 +18,7 @@ class \@Base
     typedef std::vector<int> VectorInt;
 
     static size_t const s_unavailable = std::numeric_limits<size_t>::max();
+    static constexpr char const s_istream[] = "(istream)";
 
     enum 
     {
@@ -65,7 +66,6 @@ private:
         // Its member get() returns the next input character
 $insert inputInterface
 
-protected:
     struct StreamStruct
     {
         std::string pushedName;
@@ -73,6 +73,7 @@ protected:
     };
 
 private:
+    std::string d_cwd;
     std::vector<StreamStruct>    d_streamStack;
 
     std::string     d_filename;             // name of the currently processed
@@ -93,8 +94,6 @@ private:
     std::istream *d_in;                     // points to the input stream
     std::shared_ptr<std::istringstream> d_line; // holds line fm d_in
     
-    Input           *d_input;               // input now in d_streamStack
-
     std::string     d_matched;              // matched characters
     std::string     d_lopMatched;           // matched lop-rule characters 
     std::string::iterator d_lopIter;
@@ -107,8 +106,8 @@ private:
 
     size_t (\@Base::*d_get)() = &\@Base::getInput;
 
-protected:
-    std::istream   *d_in_;
+$insert inputDeclaration
+    std::istream    *d_in_;
     int d_token_;                          // returned by lex_
 
 $insert 4 debugDecl
@@ -119,10 +118,10 @@ $insert 4 declarations
 
 public:
     \@Base(\@Base const &other)             = delete;
-    \@Base &operator=(\@Base const &rhs)    = delete;
 
     bool                debug()     const;
     std::string const  &filename()  const;
+    std::string const  &cwd()       const;
     std::string const  &matched()   const;
 
     size_t              length()    const;
@@ -147,9 +146,9 @@ $ignoreInteractive END      end ignored section by generator/filter.cc
 $insert interactiveDecl
 
 protected:
-    \@Base(std::istream &in, std::ostream &out);
+    \@Base(std::istream &in, std::ostream &out, bool keepCwd = true);
 $ignoreInteractive BEGIN    this section is ignored by generator/filter.cc
-    \@Base(std::string const &infilename, std::string const &outfilename);
+    \@Base(std::string const &infilename, std::string const &outfilename, bool keepCwd = true);
 $ignoreInteractive END      end ignored section by generator/filter.cc
     ~\@Base();
 
@@ -157,6 +156,7 @@ $ignoreInteractive END      end ignored section by generator/filter.cc
     std::ostream   &out();
     void            echo() const;
     void            leave(int retValue) const;
+    void toCwd() const;
 
 //    `accept(n)' returns all but the first `n' characters of the current
 // token back to the input stream, where they will be rescanned when the
@@ -217,8 +217,7 @@ $insert startconddecl
     void p_pushStream(std::string const &name, std::istream *streamPtr);
     void setMatchedSize(size_t length);
     bool knownFinalState();
-
-    static std::string setCwd(std::string const &filename);
+    static std::string chgWorkingDir(std::string const &filename);
 
     template <typename ReturnType, typename ArgType>
     static ReturnType constexpr as(ArgType value);
@@ -289,6 +288,11 @@ inline std::string const &\@Base::matched() const
     return d_matched;
 }
 
+inline std::string const &\@Base::cwd() const
+{
+    return d_cwd;
+}
+
 inline std::string const &\@Base::filename() const
 {
     return d_filename;
